package com.google.zxing.client.android;

import android.animation.ValueAnimator;
import android.annotation.SuppressLint;
import android.content.Context;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.LinearGradient;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Shader;
import android.text.Layout;
import android.text.StaticLayout;
import android.text.TextPaint;
import android.util.AttributeSet;
import android.view.View;
import android.view.animation.DecelerateInterpolator;
import androidx.core.content.ContextCompat;
import com.google.zxing.ResultPoint;
import com.google.zxing.client.android.camera.CameraManager;
import com.hbg.lib.common.utils.PixelUtils;
import java.util.ArrayList;
import java.util.List;
import pro.huobi.R;
/* loaded from: classes.dex */
public final class ViewfinderView extends View {
    private static final long ANIMATION_DELAY = 80;
    private static final int CURRENT_POINT_OPACITY = 160;
    private static final int MAX_RESULT_POINTS = 20;
    private static final int POINT_SIZE = 6;
    private static final int[] SCANNER_ALPHA = {0, 64, 128, 192, 255, 192, 128, 64};
    public static final int style_gridding = 0;
    public static final int style_hybrid = 2;
    public static final int style_radar = 1;
    private int SCAN_VELOCITY;
    private CameraManager cameraManager;
    private int frameColor;
    private Path framePath;
    private Paint framePathPaint;
    private int framePathWith;
    private int innerCornerColor;
    private int innerCornerLength;
    private int innerCornerWidth;
    private boolean isCircle;
    private final int laserColor;
    private List<ResultPoint> lastPossibleResultPoints;
    private int leftPadding;
    private int mBoundaryColor;
    private float mBoundaryStrokeWidth;
    private float mCornerLineLenRatio;
    private int mFirstScancolor;
    private int mGriddingDensity;
    private float mGriddingLineWidth;
    private Path mGriddingPath;
    private LinearGradient mLinearGradient_Gridding;
    private LinearGradient mLinearGradient_Radar;
    private int mScanAnimatorDuration;
    private Matrix mScanMatrix;
    private Paint mScanPaint_Gridding;
    private Paint mScanPaint_Radio;
    private int mScanStyle;
    private int mScancolor;
    private int mSecondScancolor;
    private int mThirdScancolor;
    private ValueAnimator mValueAnimator;
    private final int maskColor;
    private final Paint paint;
    private List<ResultPoint> possibleResultPoints;
    private int rectRadius;
    private Bitmap resultBitmap;
    private final int resultColor;
    private final int resultPointColor;
    private Bitmap scanLight;
    private int scanLineTop;
    private int scannerAlpha;
    private String textHint;
    private int textHintBgColor;
    private int textHintColor;
    private int textHintHeight;
    private int textHintMarginTop;
    private int textHintTextSize;
    private int topPadding;

    public ViewfinderView(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        this.mBoundaryColor = -1;
        this.mBoundaryStrokeWidth = 8.0f;
        this.mGriddingLineWidth = 1.0f;
        this.mGriddingDensity = 40;
        this.mCornerLineLenRatio = 0.06f;
        this.mScanAnimatorDuration = 1800;
        this.mScanStyle = 2;
        this.paint = new Paint(1);
        Resources resources = getResources();
        this.maskColor = resources.getColor(R.color.viewfinder_mask);
        this.resultColor = resources.getColor(R.color.result_view);
        this.laserColor = resources.getColor(R.color.viewfinder_laser);
        this.resultPointColor = resources.getColor(R.color.possible_result_points);
        this.scannerAlpha = 0;
        this.possibleResultPoints = new ArrayList(5);
        this.lastPossibleResultPoints = null;
        this.innerCornerColor = ContextCompat.getColor(context, (int) R.color.viewfinder_corner_color);
        this.innerCornerLength = PixelUtils.a(16.0f);
        this.innerCornerWidth = PixelUtils.a(2.5f);
        this.SCAN_VELOCITY = 4;
        this.textHintBgColor = ContextCompat.getColor(context, (int) R.color.scan_text_hint_bg);
        this.textHintMarginTop = PixelUtils.a(15.0f);
        this.textHintHeight = PixelUtils.a(30.0f);
        this.textHintColor = ContextCompat.getColor(context, (int) R.color.scan_text_hint_text_color);
        this.textHint = "";
        this.textHintTextSize = PixelUtils.a(14.0f);
        this.leftPadding = PixelUtils.a(30.0f);
        this.topPadding = PixelUtils.a(15.0f);
        Paint paint = new Paint(1);
        this.mScanPaint_Gridding = paint;
        paint.setStyle(Paint.Style.STROKE);
        this.mScanPaint_Gridding.setStrokeWidth(this.mGriddingLineWidth);
        Paint paint2 = new Paint(1);
        this.mScanPaint_Radio = paint2;
        paint2.setStyle(Paint.Style.FILL);
        this.mScancolor = resources.getColor(R.color.viewfinder_grid_color);
        this.mFirstScancolor = resources.getColor(R.color.viewfinder_grid_first_color);
        this.mSecondScancolor = resources.getColor(R.color.viewfinder_grid_second_color);
        this.mThirdScancolor = resources.getColor(R.color.viewfinder_grid_third_color);
        Matrix matrix = new Matrix();
        this.mScanMatrix = matrix;
        matrix.setTranslate(0.0f, 30.0f);
        this.framePath = new Path();
        this.framePathPaint = new Paint();
        this.frameColor = ContextCompat.getColor(context, (int) R.color.viewfinder_frame_color);
        this.framePathWith = PixelUtils.a(0.5f);
        this.rectRadius = PixelUtils.a(2.5f);
    }

    private void drawFrameBounds(Canvas canvas, Rect rect) {
        this.framePathPaint.setColor(this.frameColor);
        this.framePathPaint.setStyle(Paint.Style.STROKE);
        this.framePathPaint.setStrokeWidth(this.framePathWith);
        this.framePath.moveTo(rect.left, rect.top);
        this.framePath.lineTo(rect.left, rect.bottom);
        this.framePath.lineTo(rect.right, rect.bottom);
        this.framePath.lineTo(rect.right, rect.top);
        this.framePath.lineTo(rect.left, rect.top);
        canvas.drawPath(this.framePath, this.framePathPaint);
        this.paint.setColor(this.innerCornerColor);
        this.paint.setStyle(Paint.Style.FILL);
        int i = this.innerCornerWidth;
        int i2 = this.innerCornerLength;
        int i3 = rect.left;
        int i4 = rect.top;
        RectF rectF = new RectF(i3, i4, i3 + i, i4 + i2);
        int i5 = this.rectRadius;
        canvas.drawRoundRect(rectF, i5, i5, this.paint);
        int i6 = rect.left;
        int i7 = rect.top;
        RectF rectF2 = new RectF(i6, i7, i6 + i2, i7 + i);
        int i8 = this.rectRadius;
        canvas.drawRoundRect(rectF2, i8, i8, this.paint);
        int i9 = rect.right;
        int i10 = rect.top;
        RectF rectF3 = new RectF(i9 - i, i10, i9, i10 + i2);
        int i11 = this.rectRadius;
        canvas.drawRoundRect(rectF3, i11, i11, this.paint);
        int i12 = rect.right;
        int i13 = rect.top;
        RectF rectF4 = new RectF(i12 - i2, i13, i12, i13 + i);
        int i14 = this.rectRadius;
        canvas.drawRoundRect(rectF4, i14, i14, this.paint);
        int i15 = rect.left;
        int i16 = rect.bottom;
        RectF rectF5 = new RectF(i15, i16 - i2, i15 + i, i16);
        int i17 = this.rectRadius;
        canvas.drawRoundRect(rectF5, i17, i17, this.paint);
        int i18 = rect.left;
        int i19 = rect.bottom;
        RectF rectF6 = new RectF(i18, i19 - i, i18 + i2, i19);
        int i20 = this.rectRadius;
        canvas.drawRoundRect(rectF6, i20, i20, this.paint);
        int i21 = rect.right;
        int i22 = rect.bottom;
        RectF rectF7 = new RectF(i21 - i, i22 - i2, i21, i22);
        int i23 = this.rectRadius;
        canvas.drawRoundRect(rectF7, i23, i23, this.paint);
        int i24 = rect.right;
        int i25 = rect.bottom;
        RectF rectF8 = new RectF(i24 - i2, i25 - i, i24, i25);
        int i26 = this.rectRadius;
        canvas.drawRoundRect(rectF8, i26, i26, this.paint);
    }

    private void drawScanLight(Canvas canvas, Rect rect) {
        if (this.scanLineTop == 0) {
            this.scanLineTop = rect.top;
        }
        int i = this.scanLineTop;
        if (i >= rect.bottom - 30) {
            this.scanLineTop = rect.top;
        } else {
            this.scanLineTop = i + this.SCAN_VELOCITY;
        }
        int i2 = rect.left;
        int i3 = this.scanLineTop;
        canvas.drawBitmap(this.scanLight, (Rect) null, new Rect(i2, i3, rect.right, i3 + 30), this.paint);
    }

    private void drawTextHint(Canvas canvas, Rect rect) {
        TextPaint textPaint = new TextPaint();
        textPaint.setAntiAlias(true);
        textPaint.setFlags(1);
        textPaint.setStyle(Paint.Style.FILL);
        textPaint.setColor(this.textHintColor);
        textPaint.setTextSize(this.textHintTextSize);
        textPaint.getFontMetrics(new Paint.FontMetrics());
        StaticLayout staticLayout = new StaticLayout(this.textHint, textPaint, rect.width(), Layout.Alignment.ALIGN_CENTER, 1.0f, 0.0f, false);
        canvas.save();
        canvas.translate(rect.left, rect.bottom + this.textHintMarginTop);
        staticLayout.draw(canvas);
        canvas.restore();
    }

    private void initBoundaryAndAnimator(Rect rect) {
        if (this.mValueAnimator == null) {
            initScanValueAnim(rect.height());
        }
    }

    private void initGriddingPathAndStyle(Rect rect) {
        if (this.mGriddingPath == null) {
            this.mGriddingPath = new Path();
            float width = rect.width() / (this.mGriddingDensity + 0.0f);
            float height = rect.height() / (this.mGriddingDensity + 0.0f);
            for (int i = 0; i <= this.mGriddingDensity; i++) {
                float f = i * width;
                this.mGriddingPath.moveTo(rect.left + f, rect.top);
                this.mGriddingPath.lineTo(rect.left + f, rect.bottom);
            }
            for (int i2 = 0; i2 <= this.mGriddingDensity; i2++) {
                float f2 = i2 * height;
                this.mGriddingPath.moveTo(rect.left, rect.top + f2);
                this.mGriddingPath.lineTo(rect.right, rect.top + f2);
            }
        }
        if (this.mLinearGradient_Gridding == null) {
            LinearGradient linearGradient = new LinearGradient(0.0f, rect.top, 0.0f, rect.bottom + (rect.height() * 0.01f), new int[]{0, 0, this.mScancolor, 0}, new float[]{0.0f, 0.65f, 0.99f, 1.0f}, Shader.TileMode.CLAMP);
            this.mLinearGradient_Gridding = linearGradient;
            linearGradient.setLocalMatrix(this.mScanMatrix);
            this.mScanPaint_Gridding.setShader(this.mLinearGradient_Gridding);
        }
    }

    private void initRadarStyle(Rect rect) {
        if (this.mLinearGradient_Radar == null) {
            LinearGradient linearGradient = new LinearGradient(0.0f, rect.top, 0.0f, rect.bottom + (rect.height() * 0.01f), new int[]{0, 0, this.mFirstScancolor, this.mSecondScancolor, this.mThirdScancolor, 0}, new float[]{0.0f, 0.85f, 0.9f, 0.95f, 0.99f, 1.0f}, Shader.TileMode.CLAMP);
            this.mLinearGradient_Radar = linearGradient;
            linearGradient.setLocalMatrix(this.mScanMatrix);
            this.mScanPaint_Radio.setShader(this.mLinearGradient_Radar);
        }
    }

    public void addPossibleResultPoint(ResultPoint resultPoint) {
        List<ResultPoint> list = this.possibleResultPoints;
        synchronized (list) {
            list.add(resultPoint);
            int size = list.size();
            if (size > MAX_RESULT_POINTS) {
                list.subList(0, size - 10).clear();
            }
        }
    }

    public void drawResultBitmap(Bitmap bitmap) {
        this.resultBitmap = bitmap;
        invalidate();
    }

    public void drawViewfinder() {
        Bitmap bitmap = this.resultBitmap;
        this.resultBitmap = null;
        if (bitmap != null) {
            bitmap.recycle();
        }
        invalidate();
    }

    public void initScanValueAnim(int i) {
        ValueAnimator valueAnimator = new ValueAnimator();
        this.mValueAnimator = valueAnimator;
        valueAnimator.setDuration(this.mScanAnimatorDuration);
        this.mValueAnimator.setFloatValues(-i, 0.0f);
        this.mValueAnimator.setRepeatMode(1);
        this.mValueAnimator.setInterpolator(new DecelerateInterpolator());
        this.mValueAnimator.setRepeatCount(10000);
        this.mValueAnimator.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() { // from class: com.google.zxing.client.android.ViewfinderView.1
            @Override // android.animation.ValueAnimator.AnimatorUpdateListener
            public void onAnimationUpdate(ValueAnimator valueAnimator2) {
                if (ViewfinderView.this.mScanMatrix == null || ViewfinderView.this.mLinearGradient_Gridding == null) {
                    return;
                }
                ViewfinderView.this.mScanMatrix.setTranslate(0.0f, ((Float) valueAnimator2.getAnimatedValue()).floatValue());
                ViewfinderView.this.mLinearGradient_Gridding.setLocalMatrix(ViewfinderView.this.mScanMatrix);
                ViewfinderView.this.mLinearGradient_Radar.setLocalMatrix(ViewfinderView.this.mScanMatrix);
                ViewfinderView.this.invalidate();
            }
        });
        this.mValueAnimator.start();
    }

    @Override // android.view.View
    public void onDetachedFromWindow() {
        super.onDetachedFromWindow();
        ValueAnimator valueAnimator = this.mValueAnimator;
        if (valueAnimator != null) {
            valueAnimator.cancel();
        }
        this.mValueAnimator = null;
    }

    @Override // android.view.View
    @SuppressLint({"DrawAllocation"})
    public void onDraw(Canvas canvas) {
        CameraManager cameraManager = this.cameraManager;
        if (cameraManager == null) {
            return;
        }
        Rect framingRect = cameraManager.getFramingRect();
        Rect framingRectInPreview = this.cameraManager.getFramingRectInPreview();
        if (framingRect == null || framingRectInPreview == null) {
            return;
        }
        int width = getWidth();
        int height = getHeight();
        this.paint.setColor(this.resultBitmap != null ? this.resultColor : this.maskColor);
        float f = width;
        canvas.drawRect(0.0f, 0.0f, f, framingRect.top, this.paint);
        canvas.drawRect(0.0f, framingRect.top, framingRect.left, framingRect.bottom + 1, this.paint);
        canvas.drawRect(framingRect.right + 1, framingRect.top, f, framingRect.bottom + 1, this.paint);
        canvas.drawRect(0.0f, framingRect.bottom + 1, f, height, this.paint);
        if (this.resultBitmap != null) {
            this.paint.setAlpha(CURRENT_POINT_OPACITY);
            canvas.drawBitmap(this.resultBitmap, (Rect) null, framingRect, this.paint);
            return;
        }
        drawFrameBounds(canvas, framingRect);
        drawTextHint(canvas, framingRect);
        initBoundaryAndAnimator(framingRect);
        int i = this.mScanStyle;
        if (i == 0) {
            initGriddingPathAndStyle(framingRect);
            canvas.drawPath(this.mGriddingPath, this.mScanPaint_Gridding);
        } else if (i == 1) {
            initRadarStyle(framingRect);
            canvas.drawRect(framingRect, this.mScanPaint_Radio);
        } else if (i != 2) {
            initGriddingPathAndStyle(framingRect);
            canvas.drawPath(this.mGriddingPath, this.mScanPaint_Gridding);
        } else {
            initGriddingPathAndStyle(framingRect);
            initRadarStyle(framingRect);
            canvas.drawPath(this.mGriddingPath, this.mScanPaint_Gridding);
            canvas.drawRect(framingRect, this.mScanPaint_Radio);
        }
        postInvalidateDelayed(ANIMATION_DELAY, framingRect.left - 6, framingRect.top - 6, framingRect.right + 6, framingRect.bottom + 6);
    }

    public void setCameraManager(CameraManager cameraManager) {
        this.cameraManager = cameraManager;
    }

    public void setTextHint(String str) {
        this.textHint = str;
    }
}
